pub struct KernelCache { /* private fields */ }Expand description
A bounded LRU of compiled kernels (docs/EAGER.md 8.2).
Implementations
Sourceimpl KernelCache
impl KernelCache
Sourcepub fn new(capacity: usize) -> Self
pub fn new(capacity: usize) -> Self
A cache holding at most capacity compiled kernels (capacity is
clamped to at least 1).
Sourcepub fn get_or_create<E>(
&mut self,
key: KernelCacheKey,
create: impl FnOnce() -> Result<Box<dyn Kernel>, E>,
) -> Result<Arc<Mutex<Box<dyn Kernel>>>, E>
pub fn get_or_create<E>( &mut self, key: KernelCacheKey, create: impl FnOnce() -> Result<Box<dyn Kernel>, E>, ) -> Result<Arc<Mutex<Box<dyn Kernel>>>, E>
Return the cached kernel for key, compiling and inserting it via
create on a miss (docs/EAGER.md 8.2 get_or_create).
Sourcepub fn stats(&self) -> CacheStats
pub fn stats(&self) -> CacheStats
Current cache statistics.