pub struct KernelCacheKey {
pub op_type: String,
pub domain: String,
pub opset: u64,
pub input_shapes: Vec<Vec<usize>>,
pub input_dtypes: Vec<DataType>,
pub device: DeviceId,
}Expand description
The cache key (docs/EAGER.md 8.2 KernelCacheKey).
Two dispatches share a compiled kernel iff they agree on the op identity
(op_type, domain, opset), the input shapes, the input dtypes, and the
device. Shapes and dtypes are part of the key because kernels are compiled
specialised to concrete shapes (4.2 / 8.2).
Fields
op_type: Stringdomain: Stringopset: u64input_shapes: Vec<Vec<usize>>input_dtypes: Vec<DataType>device: DeviceIdTrait Implementations
Sourceimpl Clone for KernelCacheKey
impl Clone for KernelCacheKey
Sourcefn clone(&self) -> KernelCacheKey
fn clone(&self) -> KernelCacheKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KernelCacheKey
impl Debug for KernelCacheKey
impl Eq for KernelCacheKey
Sourceimpl Hash for KernelCacheKey
impl Hash for KernelCacheKey
Sourceimpl PartialEq for KernelCacheKey
impl PartialEq for KernelCacheKey
impl StructuralPartialEq for KernelCacheKey